@@ -1,4 +1,4 @@
-package Pcore::PDF v0.3.6;
+package Pcore::PDF v0.3.7;
 
 use Pcore -dist, -class, -const, -result;
 use Config;
@@ -438,7 +438,7 @@ Maximum number of princexml processes. Under Windows this value is always C<< 1
 
 =item generate_pdf( $self, $html, $cb )
 
-Generates PDF from C<< $html >> template. Call C<< $cb->($result) >> on finish, where C<< $result >> is a standard Pcore API result object, see L<Pcore::Util::Result> docuentation for details.
+Generates PDF from C<< $html >> template. Call C<< $cb->($result) >> on finish, where C<< $result >> is a standard Pcore API result object, see L<Pcore::Util::Result> documentation for details.
 
 =back
 
